@@ -1,10 +1,10 @@
-#! /usr/local/bin/perl -w
+#! /usr/bin/perl -w
 
 # egd.pl: The Entropy Gathering Daemon
 #  by Brian Warner <warner@lothar.com>
-#  Released Version 0.5
+#  Released Version 0.6
 #
-#  $Id: egd.pl,v 1.35 1999/03/16 08:20:37 warner Exp $
+#  $Id: egd.pl,v 1.38 1999/08/05 06:37:59 warner Exp $
 
 # This is a perl program to collect entropy from a running Unix-like system,
 # mostly through various stats calls (vmstat and friends). The output is
@@ -12,7 +12,8 @@
 # (theoretically) high-quality random data to callers over a UNIX- or TCP-
 # socket interface. This aims to provide functionality similar to the Linux
 # /dev/random device, but implemented in a fairly-portable user-space daemon
-# so that it can run on many unix-like systems.
+# so that it can run on many unix-like systems. See the README for common
+# usage details.
 
 # This program requires perl5 (5.004 should do), and the SHA module (available
 # from any CPAN mirror: see www.perl.org for details).
@@ -340,6 +341,7 @@ EOF
 	    foreach my $dir (@dirs) {
 		if (-x "$dir/$exec" or -X "$dir/$exec") {
 		    push(@execs, "$dir/$exec");
+		    last;
 		}
 	    }
 	} else {
@@ -466,6 +468,8 @@ sub shutdown_thing {
 	      if $entropy > $source->{'maxbits'};
 	    print " accepted $entropy bits\n" if $debug_gather;
 	    add_entropy($c->{'incoming'}, $entropy);
+	    print scalar(@want_entropy)," clients want entropy\n"
+	      if $debug_client;
 	    foreach my $w (@want_entropy) {
 		my $bytes = $w->{'wanted'};
 		if ($bytes * 8 > $pool_entropy) {
@@ -474,11 +478,11 @@ sub shutdown_thing {
 		$w->{'outgoing'} .= get_entropy($bytes);
 		$w->{'wanted'} -= $bytes;
 		if (!$w->{'wanted'}) {
-		    # remove it from the wants_entropy list
-		    foreach my $w1 (0 .. $#wants_entropy) {
-			if ($w == $wants_entropy[$w1]) {
+		    # remove it from the want_entropy list
+		    foreach my $w1 (0 .. $#want_entropy) {
+			if ($w == $want_entropy[$w1]) {
 			    # remove it
-			    splice(@wants_entropy, $w1, 1);
+			    splice(@want_entropy, $w1, 1);
 			    last;
 			}
 		    }
@@ -833,6 +837,8 @@ sub do_command {
 	    $c->{'outgoing'} .= get_entropy($count);
 	    substr($c->{'incoming'}, 0, 2) = "";
 	    $c->{'wanted'} -= $count;
+	    print "read blocked, they wait for $c->{'wanted'} bytes\n"
+	      if $debug_client and $c->{'wanted'};
 	    push(@want_entropy, $c) if $c->{'wanted'};
 	} elsif ($cmd[0] == 0x03 and $c->{'canwrite'}) {
 	    print "cmd: ",unpack("H*",$c->{'incoming'}),"\n" if $debug_client;
